@@ -1,4 +1,9 @@
-__all__ = ['CacheHandler', 'CacheFileHandler', 'DjangoSessionCacheHandler', 'MemoryCacheHandler']
+__all__ = [
+    'CacheHandler',
+    'CacheFileHandler',
+    'DjangoSessionCacheHandler',
+    'MemoryCacheHandler',
+    'RedisCacheHandler']
 
 import errno
 import json
@@ -6,6 +11,8 @@ import logging
 import os
 from spotipy.util import CLIENT_CREDS_ENV_VARS
 
+from redis import RedisError
+
 logger = logging.getLogger(__name__)
 
 
@@ -138,3 +145,37 @@ class DjangoSessionCacheHandler(CacheHandler):
             self.request.session['token_info'] = token_info
         except Exception as e:
             logger.warning("Error saving token to cache: " + str(e))
+
+
+class RedisCacheHandler(CacheHandler):
+    """
+    A cache handler that stores the token info in the Redis.
+    """
+
+    def __init__(self, redis, key=None):
+        """
+        Parameters:
+            * redis: Redis object provided by redis-py library
+            (https://github.com/redis/redis-py)
+            * key: May be supplied, will otherwise be generated
+                   (takes precedence over `token_info`)
+        """
+        self.redis = redis
+        self.key = key if key else 'token_info'
+
+    def get_cached_token(self):
+        token_info = None
+        try:
+            token_info = self.redis.get(self.key)
+            if token_info:
+                return json.loads(token_info)
+        except RedisError as e:
+            logger.warning('Error getting token from cache: ' + str(e))
+
+        return token_info
+
+    def save_token_to_cache(self, token_info):
+        try:
+            self.redis.set(self.key, json.dumps(token_info))
+        except RedisError as e:
+            logger.warning('Error saving token to cache: ' + str(e))
