@@ -633,7 +633,7 @@ class Spotify(object):
         """ Get full details of the tracks of a playlist.
 
             Parameters:
-                - playlist_id - the id of the playlist
+                - playlist_id - the playlist ID, URI or URL
                 - fields - which fields to return
                 - limit - the maximum number of tracks to return
                 - offset - the index of the first track to return
@@ -661,7 +661,7 @@ class Spotify(object):
         """ Get full details of the tracks and episodes of a playlist.
 
             Parameters:
-                - playlist_id - the id of the playlist
+                - playlist_id - the playlist ID, URI or URL
                 - fields - which fields to return
                 - limit - the maximum number of tracks to return
                 - offset - the index of the first track to return
@@ -683,7 +683,7 @@ class Spotify(object):
         """ Get cover of a playlist.
 
             Parameters:
-                - playlist_id - the id of the playlist
+                - playlist_id - the playlist ID, URI or URL
         """
         plid = self._get_id("playlist", playlist_id)
         return self._get("playlists/%s/images" % (plid))
@@ -1913,7 +1913,7 @@ class Spotify(object):
             if type != fields[-2]:
                 logger.warning('Expected id of type %s but found type %s %s',
                                type, fields[-2], id)
-            return fields[-1]
+            return fields[-1].split("?")[0]
         fields = id.split("/")
         if len(fields) >= 3:
             itype = fields[-2]
